#
# spec file for package openCOLLADA
#
# Copyright (c) 2015 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%global sover 0.2
%global commit 3335ac164e68b2512a40914b14c74db260e6ff7d
%global shortcommit 3335ac1
%global upname OpenCOLLADA
%global libname lib%{upname}0
Name:           openCOLLADA
Version:        1_%{shortcommit}
Release:        5.4
Summary:        Collada 3D import and export libraries
License:        MIT
Group:          System/Libraries
Url:            https://collada.org/mediawiki/index.php/OpenCOLLADA
## https://github.com/KhronosGroup/OpenCOLLADA/archive/%%{commit}/
Source0:        %{upname}-%{shortcommit}.tar.bz2
# PATCH-FIX-UPSTREAM use proper paths in cmake for install
Patch0:         opencollada-cmake.patch
# PATCH-FIX-UPSTREAM add missing includes
Patch1:         opencollada-includes.patch
# PATCH-FIX-UPSTREAM link to required libraries
Patch2:         opencollada-no-undefined.patch
BuildRequires:  cmake
BuildRequires:  dos2unix
BuildRequires:  fftw-devel
BuildRequires:  gcc-c++
BuildRequires:  pkgconfig(libpcre)
BuildRequires:  pkgconfig(libpcrecpp)
BuildRequires:  pkgconfig(libxml-2.0)
BuildRequires:  pkgconfig(zlib)

%description
COLLADA is a royalty-free XML schema that enables digital asset
exchange within the interactive 3D industry.
OpenCOLLADA is a Google summer of code opensource project providing
libraries for 3D file interchange between applications like blender.
COLLADABaseUtils          Utils used by many of the other projects
COLLADAFramework          Datamodel used to load COLLADA files
COLLADAStreamWriter       Sources (Library to write COLLADA files)
COLLADASaxFrameworkLoader Library that loads COLLADA files in a sax
                          like manner into the framework data model
COLLADAValidator          XML validator for COLLADA files, based on
                          the COLLADASaxFrameworkLoader
GeneratedSaxParser        Library used to load xml files in the way
                          used by COLLADASaxFrameworkLoader

%package -n %{libname}
Summary:        Collada 3D import and export libraries
Group:          System/Libraries

%description -n %{libname}
COLLADA is a royalty-free XML schema that enables digital asset
exchange within the interactive 3D industry.
OpenCOLLADA is a Google summer of code opensource project providing
libraries for 3D file interchange between applications like blender.
COLLADABaseUtils          Utils used by many of the other projects
COLLADAFramework          Datamodel used to load COLLADA files
COLLADAStreamWriter       Sources (Library to write COLLADA files)
COLLADASaxFrameworkLoader Library that loads COLLADA files in a sax
                          like manner into the framework data model
COLLADAValidator          XML validator for COLLADA files, based on
                          the COLLADASaxFrameworkLoader
GeneratedSaxParser        Library used to load xml files in the way
                          used by COLLADASaxFrameworkLoader

%package        doc
Summary:        Developer documentation for %{name}
Group:          Documentation
Requires:       %{libname} = %{version}
BuildArch:      noarch

%description doc
This package provides documentation for %{name}.

%package        devel
Summary:        Include files for openCOLLADA development
Group:          Development/Libraries
Requires:       %{libname} = %{version}

%description devel
This package provides the include files necessary to build and
develop with the %{name} export and import libraries.

%package        utils
Summary:        XML validator for COLLADA files
Group:          Development/Tools
Requires:       %{libname} = %{version}

%description utils
XML validator for COLLADA files, based on the COLLADASaxFrameworkLoader.

%prep
%setup -q -n %{upname}-%{commit}
%patch0 -p1 -b .cmake
%patch1 -p0 -b .includes
%patch2 -p1 -b .undefined

# Remove unused bundled libraries
rm -rf Externals/{Cg,expat,lib3ds,LibXML,MayaDataModel,pcre,zlib,zziplib}

# Add some docs, need to fix eol encoding with dos2unix in some files.
find ./ -name .project -delete
cp -pf COLLADAStreamWriter/README README.COLLADAStreamWriter
cp -pf COLLADAStreamWriter/LICENSE ./

iconv -f ISO_8859-1 -t utf-8 COLLADAStreamWriter/AUTHORS > \
  COLLADAStreamWriter/AUTHORS.tmp
touch -r COLLADAStreamWriter/AUTHORS COLLADAStreamWriter/AUTHORS.tmp
mv COLLADAStreamWriter/AUTHORS.tmp COLLADAStreamWriter/AUTHORS

dos2unix -f -k README.COLLADAStreamWriter
dos2unix -f -k LICENSE
dos2unix -f -k README
find htdocs/ -name *.php -exec dos2unix -f {} \;
find htdocs/ -name *.css -exec dos2unix -f {} \;

%build
%cmake \
       -DUSE_STATIC=OFF \
       -DUSE_SHARED=ON \
       -Dsoversion=%{sover}

make %{?_smp_mflags}

%install
%cmake_install

# Manually install binary
mkdir -p %{buildroot}%{_bindir}/
install -p -m 0755 build/bin/* %{buildroot}%{_bindir}/

# Install MathMLSolver headers
mkdir -p %{buildroot}%{_includedir}/MathMLSolver
cp -a Externals/MathMLSolver/include/* %{buildroot}%{_includedir}/MathMLSolver/

%post -n %{libname} -p /sbin/ldconfig

%postun -n %{libname} -p /sbin/ldconfig

%files -n %{libname}
%defattr(-,root,root)
%doc README LICENSE README.COLLADAStreamWriter COLLADAStreamWriter/AUTHORS
%{_libdir}/lib*.so.%{sover}

%files doc
%defattr(-,root,root)
%doc htdocs/

%files devel
%defattr(-,root,root)
%{_libdir}/*.so
%{_libdir}/cmake/*
%{_includedir}/*

%files utils
%defattr(-,root,root)
%{_bindir}/*

%changelog
* Tue Aug  4 2015 davejplater@gmail.com
- Update to version 1_3335ac1 to enable blender to build with
  openCOLLADA again.
- Reworked opencollada-includes.patch
* Sat Jan  3 2015 tchvatal@suse.com
- Update package to match what is done in Fedora + what is needed
  for libreoffice. Move from svn snapshot to git snapshot
- Added patches:
  * opencollada-cmake.patch
  * opencollada-includes.patch
  * opencollada-no-undefined.patch
- Obsoleted patches:
  * openCOLLADA-COLLADABU_ASSERT.patch
  * openCOLLADA-cmakelinuxbuild.patch
  * openCOLLADA-gcc47.patch
* Mon Mar 26 2012 dimstar@opensuse.org
- Update to svn 868:
  + Support make install target
  + Fixes build with gcc 4.7
- Rebase openCOLLADA-cmakelinuxbuild.patch
- Add openCOLLADA-gcc47.patch: Fix some more gcc 4.7 issues.
* Sun May  8 2011 davejplater@gmail.com
- Fix for build flags included in openCOLLADA-cmakelinuxbuild.patch
  by adding -O2 to all builds except openCOLLADASaxFrameworkLoader.
* Fri May  6 2011 davejplater@gmail.com
- Moved the headers in devel subpackage to a named directory under
  /usr/include/<library name>
* Fri May  6 2011 davejplater@gmail.com
- Bumped library revision to 1 due to build changes.
* Tue May  3 2011 davejplater@gmail.com
- Update to svn 839.
- Fixed build with openCOLLADA-COLLADABU_ASSERT.patch.
- Upstream changes :
  * add hash_multimap
  * clean up header
  * fix asserts
* Sat Apr 23 2011 davejplater@gmail.com
- Switched to cmake build system and improved library versioning
  using openCOLLADA-cmakelinuxbuild.patch from Fedora with changes.
- libUTF, libbuffer and libftoa are no longer packaged and are
  statically linked to the openCOLLADA libs that use them.
* Thu Mar 31 2011 davejplater@gmail.com
- Update to svn836
- Upstream changes :
  * fix validation preprocessor flag
  * inti member variables
  * fix uri copy ctor, add missing includes
  * replace asserts
  * fix import
  * fix crash in utf conversion with recent gcc
  * replace asserts by custom assert
* Fri Feb 11 2011 davejplater@gmail.com
- Update to svn827
- Upstream changes:
  * fix Issue 125: cgfx shader source file is not honoring the
  search path on export.
  * fix Issue 89: CONTINUITY semantic is not defined. Define all
  semantics in COLLADASWInputList.h
  * partially fix Issue 71: wrong opacity for effects without set
  transparency
  * fix Issue 65: COLLADASaxFWL::Loader::loadDocument() don't check
  if the file correctly loads
  * fix Issue 62: build fixes for linux (gcc 4.4.3)
  * ignore bin and lib folder in pcre
  * Issue 35: IWriter start, cancel, and finish methods not called
  * remove precompiled pcre pattern from source
  * fix Issue 122: Root::loadDocument("../a/b/c.dae") attempts to
  open "../a/a/b/c.dae"
  * Issue 145: std::terminate() while loading lightwave dae through
  OpenCOLLADAValidator
  * fix Issue 146: OpenCOLLADAValidator crash
  COLLADASaxFWL::LibraryEffectsLoader::handleTexture
  * fix Issue 151: CMakeLists.txt overwrites custom CMAKE_CXX_FLAGS
  * Issue 153: crash in <articulated_system> improvements in
  kinematics loader related to mathml
* Fri Jan  7 2011 davejplater@gmail.com
- Spec file change to fix SLE_11_SP1 build made by repabuild.
* Mon Dec 27 2010 davejplater@gmail.com
- Update to svn788
- Upstream changes
  * fix Issue 148: Glitch in ftoa and dtoa (rename variables)
* Mon Nov 22 2010 davejplater@gmail.com
- Update to svn785
- Prevent build of dae2ogre with openCOLLADA-nodae2ogre.patch
- Upstream changes :
  * apply path from Issue 4: CMake or Scons
  * fix performance issue with many materials
  * fix: do not write empty <extra> element in <profile_COMMON>
  * apply patch (only first change) provided in Issue 136: Fix for
  color sets not exporting in colladaMaya
  * fix Issue 137: SetParam does not properly export float<n> with
  0's in it
* Sat Nov  6 2010 davejplater@gmail.com
- Update to svn 779 Removed openCOLLADA-assign_value.patch which is
  already incorporated in this revision.
- Upstream changes :
  * fix Issue 126: cgfx shader source file is not honoring the search
  path on export.
  * apply patch provided in Issue 4: CMake or Scons (add cmake files)
  * fix Issue 132: Small fix from compiling blender - collada with
  - Wall -Werror
  * fix Issue 131: Gcc will be initialized after warning fixes
* Tue Oct 26 2010 pth@suse.de
- Actually assign the passed value in setter function.
- Manually strip libraries
* Sun Oct 24 2010 davejplater@gmail.com
- Added patch COLLADA-linuxbuild.patch to fix shared lib build includes.
- Added patch openCOLLADA-buildflags.patch for optflags.
- Added patch openCOLLADA-soname.patch to add sonames to libs.
* Mon Oct 18 2010 davejplater@gmail.com
- Created new package openCOLLADA needed by blender-2.5x
- OpenCOLLADA is a stream based reader and writer library for
  COLLADA files. support@opencollada.org
